pub struct ImportIAMResult {
pub skipped: IAMEntities,
pub removed: IAMEntities,
pub added: IAMEntities,
pub failed: IAMErrEntities,
}Expand description
ImportIAMResult - represents the structure iam import response
Fields
skipped: IAMEntitiesSkipped entries while import This could be due to groups, policies etc missing for imported entries. We dont fail hard in this case and
removed: IAMEntitiesRemoved entries - this mostly happens for policies where empty might be getting imported and that’s invalid
added: IAMEntitiesNewly added entries
failed: IAMErrEntitiesFailed entries while import. This would have details of failed entities with respective errors